/*
  ImageMagick Image Color methods.
*/
#ifndef _MAGICK_COLOR_PRIVATE_H
#define _MAGICK_COLOR_PRIVATE_H

#if defined(__cplusplus) || defined(c_plusplus)
extern "C" {
#endif

#include <magick/color.h>
#include <magick/error.h>

static inline IndexPacket ConstrainColormapIndex(Image *image,
  const unsigned long index)
{
  if (index >= image->colors)
    {
      (void) ThrowMagickException(&image->exception,GetMagickModule(),
        CorruptImageError,"InvalidColormapIndex",image->filename);
      return(0);
    }
  return((IndexPacket) index);
}

static inline void SetMagickPixelPacket(const PixelPacket *color,
  const IndexPacket *index,MagickPixelPacket *pixel)
{
  pixel->red=(MagickRealType) color->red;
  pixel->green=(MagickRealType) color->green;
  pixel->blue=(MagickRealType) color->blue;
  if (pixel->matte != MagickFalse)
    pixel->opacity=(MagickRealType) color->opacity;
  if ((pixel->colorspace == CMYKColorspace) &&
      (index != (const IndexPacket *) NULL))
    pixel->index=(MagickRealType) (*index);
}

static inline void SetPixelPacket(const MagickPixelPacket *pixel,
  PixelPacket *color,IndexPacket *index)
{
  color->red=RoundToQuantum(pixel->red);
  color->green=RoundToQuantum(pixel->green);
  color->blue=RoundToQuantum(pixel->blue);
  if (pixel->matte != MagickFalse)
    color->opacity=RoundToQuantum(pixel->opacity);
  if ((pixel->colorspace == CMYKColorspace) && (index != (IndexPacket *) NULL))
    *index=RoundToQuantum(pixel->index);
}

#if defined(__cplusplus) || defined(c_plusplus)
}
#endif

#endif
